@@ -34,13 +34,16 @@ class FlaskEaseAPI():
         blueprint_name: str = None,
         open_api_version: str = "3.0.3",
         app_version: str = "0.1.0",
-        auth_scheme=None
+        auth_scheme=None,
+        import_name=__name__,
+        **kwargs
     ):
         self.blueprint_name = blueprint_name
+
         if blueprint_name:
-            self.app = Blueprint(blueprint_name, __name__)
+            self.app = Blueprint(blueprint_name, import_name, **kwargs)
         else:
-            self.app = Flask(__name__)
+            self.app = Flask(import_name, **kwargs)
 
         self.app_version = app_version
         self.title = title
@@ -308,7 +311,8 @@ class FlaskEaseAPI():
             ["GET"],
             response_model,
             tags,
-            auth_required
+            auth_required,
+            responses
         )
 
     def post(
@@ -324,7 +328,8 @@ class FlaskEaseAPI():
             ["POST"],
             response_model,
             tags,
-            auth_required
+            auth_required,
+            responses
         )
 
     def put(
@@ -340,7 +345,8 @@ class FlaskEaseAPI():
             ["PUT"],
             response_model,
             tags,
-            auth_required
+            auth_required,
+            responses
         )
 
     def patch(
@@ -356,7 +362,8 @@ class FlaskEaseAPI():
             ["PATCH"],
             response_model,
             tags,
-            auth_required
+            auth_required,
+            responses
         )
 
     def delete(
@@ -372,7 +379,8 @@ class FlaskEaseAPI():
             ["DELETE"],
             response_model,
             tags,
-            auth_required
+            auth_required,
+            responses
         )
 
     def extend(self, blueprints: list):
